require 'logstash_formatter'
require 'json'
require 'rspec/core/reporter'

RSpec.describe LogstashFormatter do
  include FormatterSupport

  it "can be loaded via `--format logstash`" do
    output = run_example_specs_with_formatter("logstash", :normalize_output => false, :seed => 42)
    #NOT EMPTY ?
parsed = JSON.parse(output)
    expect(parsed.keys).to include("examples", "summary", "summary_line", "seed")
  end

  it "outputs expected json" do
    its = []
    group = RSpec.describe("one apiece") do
      its.push it("succeeds") { expect(1).to eq 1 }
    end
    succeeding_line = __LINE__ - 4
    failing_line = __LINE__ - 4
    pending_line = __LINE__ - 4

    now = Time.now
    allow(Time).to receive(:now).and_return(now)
    reporter.report(2) do |r|
      group.run(r)
    end

    # grab the actual backtrace -- kind of a cheat
    this_file = relative_path(__FILE__)

    expected = {
      :id => its[0].id,
      :description => "succeeds",
      :full_description => "one apiece succeeds",
      :status => "passed",
      :file_path => this_file,
      :line_number => succeeding_line,
      :hostname => "R2D2",
      :started_at => "2017",
      :run_time => formatter.output_hash[:run_time],
      :pending_message => nil,
    }
    expect(formatter.output_hash).to eq expected
    expect(formatter_output.string).to eq expected.to_json
  end
end

